==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMGPM/src/MGPMrInitialize.c <==
/*
	Copyright (C) 2005  Michael C. Shultz

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:

	1. Redistributions of source code must retain the above copyright
	   notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

	Michael C. Shultz
	ringworm01@gmail.com
	Box 3238 Landers, CA 92285
*/

#include	<libMGPM.h>

int	MGPMrInitialize( structProperty* property )
{
	/* char	id[]	= "MGPMrInitize"; */
	int	stringSize	= 0;
	int	errorCode	= 0;

	/*
	 * helpFile
	 */
	stringSize				= strlen( SHAREDIR ) + strlen( HELPFILE );
	property->helpFile			= calloc( stringSize + 1, 1 );
	strcat( property->helpFile, SHAREDIR );
	strcat( property->helpFile, HELPFILE );

	/*
	 * pm-020.conf
	 */
	stringSize				= strlen(ETCDIR) + strlen(CONFIGURE_CONF);
	property->configConfFileName		= calloc( stringSize + 1, 1 );
	strcpy(property->configConfFileName, ETCDIR);
	strcat(property->configConfFileName, CONFIGURE_CONF);

	/*
	 * availableDependenciesDb
	 */
	stringSize				= strlen(SHAREDIR) + strlen(PORTS_AVAILABLE_DEPENDENCIES_DB);
	property->availableDependenciesDbFileName	= calloc( stringSize + 1, 1 );
	strcat( property->availableDependenciesDbFileName, SHAREDIR );
	strcat( property->availableDependenciesDbFileName, PORTS_AVAILABLE_DEPENDENCIES_DB );
	MGmSetString( property->fieldAvailableDependenciesDbPortDir,		"fieldAvailableDependenciesDbPortDir" );
	MGmSetString( property->fieldAvailableDependenciesDbPortName,		"fieldAvailableDependenciesDbPortName" );
	MGmSetString( property->fieldAvailableDependenciesDbDependencyDir,	"fieldAvailableDependenciesDbDependencyDir" );
	MGmSetString( property->fieldAvailableDependenciesDbDependencyName,	"fieldAvailableDependenciesDbDependencyName" );
	MGmSetString( property->fieldAvailableDependenciesDbDependType,		"fieldAvailableDependenciesDbDependType" );

	/*
	 * availablePortsDb
	 */
	stringSize				= strlen(SHAREDIR) + strlen(PORTS_AVAILABLE_DB);
	property->availablePortsDbFileName	= calloc( stringSize + 1, 1 );
	strcat(property->availablePortsDbFileName, SHAREDIR);
	strcat(property->availablePortsDbFileName, PORTS_AVAILABLE_DB);
	MGmSetString( property->fieldAvailablePortsDbPortName,	"fieldAvailablePortsDbPortName" );
	MGmSetString( property->fieldAvailablePortsDbPortDir,	"fieldAvailablePortsDbPortDir" );
	MGmSetString( property->fieldAvailablePortsDbFlag,	"fieldAvailablePortsDbFlag" );

	/*
	 * cacheDb
	 */	
	stringSize				= strlen( SHAREDIR ) + strlen( PORTS_CACHE_DB );
	property->cacheDbFileName		= calloc( stringSize + 1, 1 );
	strcat(property->cacheDbFileName, SHAREDIR);
	strcat(property->cacheDbFileName, PORTS_CACHE_DB);
	MGmSetString( property->fieldCacheDbPortDir,		"fieldCacheDbPortDir" );
	MGmSetString( property->fieldCacheDbAvailablePortName,	"fieldCacheDbAvailablePortName" );
	MGmSetString( property->fieldCacheDbMakeFileSize,	"fieldCacheDbMakeFileSize" );
	MGmSetString( property->fieldCacheDbMakeFileTime,	"fieldCacheDbMakeFileTime" );

	/*
	 * commandLineDb
	 */	
	stringSize				= strlen( SHAREDIR ) + strlen( COMMANDLINE_DB );
	property->commandLineDbFileName		= calloc( stringSize + 1, 1 );
	strcat( property->commandLineDbFileName, SHAREDIR );
	strcat( property->commandLineDbFileName, COMMANDLINE_DB );
	MGmSetString( property->fieldCommandLineDbKey,		"fieldCommandLineDbKey" );	/* commandLineDb field 0 */
	MGmSetString( property->fieldCommandLineDbValue,	"fieldCommandLineDbValue" );	/* commandLineDb field 1 */

	/*
	 * configDb
	 */	
	stringSize				= strlen(SHAREDIR) + strlen(CONFIGURE_DB);
	property->configDbFileName		= (char*)calloc( stringSize + 1, 1 );
	strcat(property->configDbFileName, SHAREDIR);
	strcat(property->configDbFileName, CONFIGURE_DB);
	MGmSetString( property->fieldConfigDbKey,	"fieldConfigDbKey" );
	MGmSetString( property->fieldConfigDbValue,	"fieldConfigDbValue" );

	/*
	 * dependencyPortsDb
	 */	
	stringSize				= strlen( SHAREDIR ) + strlen( PORT_DEPENDENCIES_DB );
	property->dependencyPortsDbFileName	= (char*)calloc( stringSize + 1, 1 );
	strcat(property->dependencyPortsDbFileName, SHAREDIR);
	strcat(property->dependencyPortsDbFileName, PORT_DEPENDENCIES_DB );
	MGmSetString( property->fieldDependencyDbPortDir,		"fieldDependencyDbPortDir" );
	MGmSetString( property->fieldDependencyDbPortName,		"fieldDependencyDbPortName" );
	MGmSetString( property->fieldDependencyDbDependencyPortDir,	"fieldDependencyDbDependencyPortDir" );
	MGmSetString( property->fieldDependencyDbDependencyPortName,	"fieldDependencyDbDependencyPortName" );

	/*
	 * ignoreDb
	 */	
	stringSize				= strlen(SHAREDIR) + strlen(IGNORE_DB);
	property->ignoreDbFileName		= calloc( stringSize + 1, 1 );
	strcat(property->ignoreDbFileName, SHAREDIR);
	strcat(property->ignoreDbFileName, IGNORE_DB);
	MGmSetString( property->fieldignoreDbPortDir,	"fieldIgnoreDbPortDir" );		/* ignoreDb field 0 */
	MGmSetString( property->fieldIgnoreDbReason,	"fieldIgnoreDbReason" );		/* ignoreDb field 1 */

	/*
	 * installedPortsDb
	 */	
	stringSize				= strlen( SHAREDIR ) + strlen( PORTS_INSTALLED_DB );
	property->installedPortsDbFileName	= calloc( stringSize + 1, 1 );
	strcat( property->installedPortsDbFileName, SHAREDIR );
	strcat( property->installedPortsDbFileName, PORTS_INSTALLED_DB );
	MGmSetString( property->fieldInstalledPortsDbPortName,	"fieldInstalledPortsDbPortName" );
	MGmSetString( property->fieldInstalledPortsDbPortDir,	"fieldInstalledPortsDbPortDir" );
	MGmSetString( property->fieldInstalledPortsDbFlag,	"fieldInstalledPortsDbFlag" );

	/*
	 * oldPortsDb
	 */	
	stringSize				= strlen(SHAREDIR) + strlen(PORTS_OLD_DB);
	property->oldPortsDbFileName		= calloc( stringSize + 1, 1 );
	strcat(property->oldPortsDbFileName, SHAREDIR);
	strcat(property->oldPortsDbFileName, PORTS_OLD_DB);
	MGmSetString( property->fieldOldPortsDbOldPortDir,	"fieldOldPortsDbOldPortDir" );
	MGmSetString( property->fieldOldPortsDbOldPortName,	"fieldOldPortsDbOldPortName" );
	MGmSetString( property->fieldOldPortsDbReason,		"fieldOldPortsDbReason" );
	MGmSetString( property->fieldOldPortsDbNewPortName,	"fieldOldPortsDbNewPortName" );
	MGmSetString( property->fieldOldPortsDbNewPortDir,	"fieldOldPortsDbNewPortDir" );

	/*
	 * strikesDb
	 */
	stringSize				= strlen( SHAREDIR ) + strlen( STRIKES_DB );
	property->strikesDbFileName		= calloc( stringSize + 1, 1 );
	strcat(property->strikesDbFileName, SHAREDIR);
	strcat(property->strikesDbFileName, STRIKES_DB );
	MGmSetString( property->fieldStrikesDbPortDir,	"fieldStrikesDbPortDir" );
	MGmSetString( property->fieldStrikesIDX,	"fieldStrikesIDX" );
	
	return( 0 );
}

==> portmanager-0.4.1.tar.gz: portmanager-0.4.1/libMGPM/src/MGPMrInitialize.c <==
/*
	Copyright (C) 2005  Michael C. Shultz

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:

	1. Redistributions of source code must retain the above copyright
	   notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	   notice, this list of conditions and the following disclaimer in the
	   documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

	Michael C. Shultz
	ringworm01@gmail.com
	Box 3238 Landers, CA 92285
*/

#include	<libMGPM.h>

int	MGPMrInitialize( structProperty* property )
{
	char	id[]		= "MGPMrInitize";
	int	stringSize	= 0x1ff;
	int	errorCode	= 0;

	/*
	 * helpFile
	 */
	property->helpFile			= calloc( stringSize + 1, 1 );
	MGmStrcat( property->helpFile, SHAREDIR );
	MGmStrcat( property->helpFile, HELPFILE );

	/*
	 * pm-020.conf
	 */
	property->configConfFileName		= calloc( stringSize + 1, 1 );
	MGmStrcpy(property->configConfFileName, ETCDIR);
	MGmStrcat(property->configConfFileName, "/portmanager/" );
	MGmStrcat(property->configConfFileName, CONFIGURE_CONF);

	/*
	 * availableDependenciesDb
	 */
	property->availableDependenciesDbFileName	= calloc( stringSize + 1, 1 );
	MGmStrcat( property->availableDependenciesDbFileName, SHAREDIR );
	MGmStrcat( property->availableDependenciesDbFileName, PORTS_AVAILABLE_DEPENDENCIES_DB );
	MGmSetString( property->fieldAvailableDependenciesDbPortDir,		"fieldAvailableDependenciesDbPortDir" );
	MGmSetString( property->fieldAvailableDependenciesDbPortName,		"fieldAvailableDependenciesDbPortName" );
	MGmSetString( property->fieldAvailableDependenciesDbDependencyDir,	"fieldAvailableDependenciesDbDependencyDir" );
	MGmSetString( property->fieldAvailableDependenciesDbDependencyName,	"fieldAvailableDependenciesDbDependencyName" );
	MGmSetString( property->fieldAvailableDependenciesDbDependType,		"fieldAvailableDependenciesDbDependType" );

	/*
	 * availablePortsDb
	 */
	property->availablePortsDbFileName	= calloc( stringSize + 1, 1 );
	MGmStrcat(property->availablePortsDbFileName, SHAREDIR);
	MGmStrcat(property->availablePortsDbFileName, PORTS_AVAILABLE_DB);
	MGmSetString( property->fieldAvailablePortsDbPortName,	"fieldAvailablePortsDbPortName" );
	MGmSetString( property->fieldAvailablePortsDbPortDir,	"fieldAvailablePortsDbPortDir" );
	MGmSetString( property->fieldAvailablePortsDbFlag,	"fieldAvailablePortsDbFlag" );

	/*
	 * cacheDb
	 */	
	property->cacheDbFileName		= calloc( stringSize + 1, 1 );
	MGmStrcat(property->cacheDbFileName, SHAREDIR);
	MGmStrcat(property->cacheDbFileName, PORTS_CACHE_DB);
	MGmSetString( property->fieldCacheDbPortDir,		"fieldCacheDbPortDir" );
	MGmSetString( property->fieldCacheDbAvailablePortName,	"fieldCacheDbAvailablePortName" );
	MGmSetString( property->fieldCacheDbMakeFileSize,	"fieldCacheDbMakeFileSize" );
	MGmSetString( property->fieldCacheDbMakeFileTime,	"fieldCacheDbMakeFileTime" );

	/*
	 * commandLineDb
	 */	
	property->commandLineDbFileName		= calloc( stringSize + 1, 1 );
	MGmStrcat( property->commandLineDbFileName, SHAREDIR );
	MGmStrcat( property->commandLineDbFileName, COMMANDLINE_DB );
	MGmSetString( property->fieldCommandLineDbKey,		"fieldCommandLineDbKey" );	/* commandLineDb field 0 */
	MGmSetString( property->fieldCommandLineDbValue,	"fieldCommandLineDbValue" );	/* commandLineDb field 1 */

	/*
	 * configDb
	 */	
	property->configDbFileName		= (char*)calloc( stringSize + 1, 1 );
	MGmStrcat(property->configDbFileName, SHAREDIR);
	MGmStrcat(property->configDbFileName, CONFIGURE_DB);
	MGmSetString( property->fieldConfigDbKey,	"fieldConfigDbKey" );
	MGmSetString( property->fieldConfigDbValue,	"fieldConfigDbValue" );

	/*
	 * dependencyPortsDb
	 */	
	property->dependencyPortsDbFileName	= (char*)calloc( stringSize + 1, 1 );
	MGmStrcat(property->dependencyPortsDbFileName, SHAREDIR);
	MGmStrcat(property->dependencyPortsDbFileName, PORT_DEPENDENCIES_DB );
	MGmSetString( property->fieldDependencyDbPortDir,		"fieldDependencyDbPortDir" );
	MGmSetString( property->fieldDependencyDbPortName,		"fieldDependencyDbPortName" );
	MGmSetString( property->fieldDependencyDbDependencyPortDir,	"fieldDependencyDbDependencyPortDir" );
	MGmSetString( property->fieldDependencyDbDependencyPortName,	"fieldDependencyDbDependencyPortName" );

	/*
	 * ignoreDb
	 */	
	property->ignoreDbFileName		= calloc( stringSize + 1, 1 );
	MGmStrcat(property->ignoreDbFileName, SHAREDIR);
	MGmStrcat(property->ignoreDbFileName, IGNORE_DB);
	MGmSetString( property->fieldignoreDbPortDir,	"fieldIgnoreDbPortDir" );		/* ignoreDb field 0 */
	MGmSetString( property->fieldIgnoreDbReason,	"fieldIgnoreDbReason" );		/* ignoreDb field 1 */

	/*
	 * installedPortsDb
	 */	
	property->installedPortsDbFileName	= calloc( stringSize + 1, 1 );
	MGmStrcat( property->installedPortsDbFileName, SHAREDIR );
	MGmStrcat( property->installedPortsDbFileName, PORTS_INSTALLED_DB );
	MGmSetString( property->fieldInstalledPortsDbPortName,	"fieldInstalledPortsDbPortName" );
	MGmSetString( property->fieldInstalledPortsDbPortDir,	"fieldInstalledPortsDbPortDir" );
	MGmSetString( property->fieldInstalledPortsDbFlag,	"fieldInstalledPortsDbFlag" );

	/*
	 * oldPortsDb
	 */	
	property->oldPortsDbFileName		= calloc( stringSize + 1, 1 );
	MGmStrcat(property->oldPortsDbFileName, SHAREDIR);
	MGmStrcat(property->oldPortsDbFileName, PORTS_OLD_DB);
	MGmSetString( property->fieldOldPortsDbOldPortDir,	"fieldOldPortsDbOldPortDir" );
	MGmSetString( property->fieldOldPortsDbOldPortName,	"fieldOldPortsDbOldPortName" );
	MGmSetString( property->fieldOldPortsDbReason,		"fieldOldPortsDbReason" );
	MGmSetString( property->fieldOldPortsDbNewPortName,	"fieldOldPortsDbNewPortName" );
	MGmSetString( property->fieldOldPortsDbNewPortDir,	"fieldOldPortsDbNewPortDir" );

	/*
	 * strikesDb
	 */
	property->strikesDbFileName		= calloc( stringSize + 1, 1 );
	MGmStrcat(property->strikesDbFileName, SHAREDIR);
	MGmStrcat(property->strikesDbFileName, STRIKES_DB );
	MGmSetString( property->fieldStrikesDbPortDir,	"fieldStrikesDbPortDir" );
	MGmSetString( property->fieldStrikesIDX,	"fieldStrikesIDX" );
	
	return( 0 );
}
